@@ -2,9 +2,9 @@
 # @Author: Noaghzil
 # @Date:   2022-08-15 11:12:05
 # @Last Modified by:   Noaghzil
-# @Last Modified time: 2022-08-15 17:24:49
+# @Last Modified time: 2022-08-16 17:43:57
 import pytest
-from tool_box.api import Http
+from min_tbox.api import Http
 
 
 @pytest.fixture(scope="session")
