@@ -6,9 +6,9 @@
   @Date: 2022-08-09 15:57:50
   @Description:
   @Email: noaghzil@gmail.com
-  @Last Modified time: 2022-08-15 17:22:25
+  @Last Modified time: 2022-08-16 17:44:00
 """
-from tool_box import filter_dict
+from min_tbox import filter_dict
 
 def test_filter_dict():
     user_info = {"title": 8, "hospital": "测试医院", "department": "内科", "gender": 1}
